﻿using System;
using System.Windows.Forms;

namespace AgencySystem
{
    public partial class RestaurantsShowPage : DataMethods
    {
        private static RestaurantsShowPage _instance;
        public static RestaurantsShowPage Instance
        {
            get
            {
                if (_instance == null)
                    _instance = new RestaurantsShowPage();
                return _instance;
            }
        }

        public RestaurantsShowPage()
        {
            InitializeComponent();
            DefaultScreen.initializeHeading(RestaurantsShowHead);
            DefaultScreen.initializePanel(RestaurantsShowPagePanel);
            DefaultScreen.initializeAddButton(RestaurantsShowPageAddRestaurant);
            RestaurantsShowHead.Text = Properties.Resources.RestaurantsHeading;
            dataGridView1.Dock = DockStyle.Fill;

            GetRestaurants();
        }

        public void GetRestaurants()
        {
            RestaurantsShowPagePanel.Controls.Clear();
            RestaurantsShowPagePanel.Controls.Add(dataGridView1);

            RestaurantsLayout.Restaurants[] allRestaurants = null;
            allRestaurants = RestaurantsLayout.GetRestaurantsFromDB();

            dataGridView1.Rows.Clear();
            dataGridView1.ColumnCount = 4;
            dataGridView1.Columns[0].Name = "Restaurant ID";
            dataGridView1.Columns[0].Width = 65;
            dataGridView1.Columns[1].Name = "Country Name";
            dataGridView1.Columns[2].Name = "Destination Name";
            dataGridView1.Columns[3].Name = "Restaurant Name";
            dataGridView1.Columns[3].Width = 160;
            string[] row = new string[4];


            if (allRestaurants != null)
            {
                int count = 1;
                foreach (RestaurantsLayout.Restaurants Restaurant in allRestaurants)
                {
                    row = new string[] { Restaurant.Id.ToString(), Restaurant.CountryName, Restaurant.DestinationName, Restaurant.Name };
                    dataGridView1.Rows.Add(row);
                    count++;
                }
            }

            DataGridViewButtonColumn showButton = new DataGridViewButtonColumn();
            dataGridView1.Columns.Add(showButton);
            showButton.Width = 60;
            showButton.HeaderText = "";
            showButton.Text = "Show";
            showButton.Name = "Show";
            showButton.UseColumnTextForButtonValue = true;

            DataGridViewButtonColumn editButton = new DataGridViewButtonColumn();
            dataGridView1.Columns.Add(editButton);
            editButton.Width = 60;
            editButton.HeaderText = "";
            editButton.Text = "Edit";
            editButton.Name = "Edit";
            editButton.UseColumnTextForButtonValue = true;

            DataGridViewButtonColumn deleteButton = new DataGridViewButtonColumn();
            dataGridView1.Columns.Add(deleteButton);
            deleteButton.Width = 60;
            deleteButton.HeaderText = "";
            deleteButton.Text = "Delete";
            deleteButton.Name = "Delete";
            deleteButton.UseColumnTextForButtonValue = true;
        }
       
        private void dataGridView1_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex >= 0)
            {
                int RestaurantId = Convert.ToInt16(dataGridView1.Rows[e.RowIndex].Cells[0].Value);
                string destinationName = dataGridView1.Rows[e.RowIndex].Cells[2].Value.ToString();
                string restaurantName = dataGridView1.Rows[e.RowIndex].Cells[3].Value.ToString();

                //SHOW
                if (e.ColumnIndex == 4)
                {
                    ShowButtonClicked(RestaurantId);
                }

                //EDIT
                if (e.ColumnIndex == 5)
                {
                    EditButtonClicked(RestaurantId);
                }

                //DELETE
                if (e.ColumnIndex == 6)
                {
                    DeleteButtonClicked(RestaurantId);
                }
            }
        }
        private void ShowButtonClicked(int id)
        {
            globalRestaurantId = id;
            DefaultScreen DefaultScreenForm = (DefaultScreen)Application.OpenForms["DefaultScreen"];
            DefaultScreenForm.ChangePage.Invoke("ShowRestaurant");
        }

        private void EditButtonClicked(int id)
        {
            globalRestaurantId = id;
            DefaultScreen DefaultScreenForm = (DefaultScreen)Application.OpenForms["DefaultScreen"];
            DefaultScreenForm.ChangePage.Invoke("EditRestaurant");
        }

        private void DeleteButtonClicked(int id)
        {
                DialogResult confirmationOfDeletion = MessageBox.Show(Properties.Resources.ConfirmRestaurantDeletionDescription, Properties.Resources.ConfirmRestaurantDeletionTitle, MessageBoxButtons.YesNo);
                if (confirmationOfDeletion == DialogResult.Yes)
                {
                    int deleted = RestaurantsLayout.DeleteRestaurant(id);
                    if (deleted == 1)
                    {
                        DefaultScreen.StatusLabel.Text = DateTime.Now + " - " + Properties.Resources.RestaurantDeletedSuccessfully;
                        DefaultScreen.ShowStatusPage(1, Properties.Resources.RestaurantDeletedSuccessfully, Properties.Resources.RestaurantDeletedSuccessfullyDesc);
                        RestaurantsShowPage.Instance.GetRestaurants();
                    }
                    else
                    {
                        DefaultScreen.StatusLabel.Text = DateTime.Now + " - " + Properties.Resources.RestaurantNotDeleted;
                        DefaultScreen.ShowStatusPage(0, Properties.Resources.RestaurantNotDeleted, Properties.Resources.RestaurantNotDeletedDesc);
                    }
                }
        }

        private void RestaurantshowPageAddRestaurant_Click(object sender, EventArgs e)
        {
            DefaultScreen DefaultScreenForm = (DefaultScreen)Application.OpenForms["DefaultScreen"];
            DefaultScreenForm.ChangePage.Invoke("AddRestaurant");
        }
    }
}
